@@ -2,7 +2,7 @@ package perl5i::2::Meta;
 
 use strict;
 use warnings;
-use v5.10.0;
+use 5.010_000;
 
 # Be very careful not to import anything.
 require Carp;
@@ -91,8 +91,10 @@ my $method_not_found = sub {
     my $class  = shift;
     my $method = shift;
 
-    Carp::croak sprintf q[Can't locate object method "%s" via package "%s"],
-      $method, $class;
+    Carp::croak(
+        sprintf q[Can't locate object method "%s" via package "%s"],
+        $method, $class
+    );
 };
 
 
@@ -114,12 +116,14 @@ sub super {
     my $class = $self->class;
 
     my $fq_method = $find_method->();
-    Carp::croak "super() called outside a method" unless $fq_method;
+    Carp::croak("super() called outside a method") unless $fq_method;
 
     my($parent, $method) = $fq_method =~ /^(.*)::(\w+)$/;
 
-    Carp::croak sprintf qq["%s" is not a parent class of "%s"], $parent, $class
-      unless $class->isa($parent);
+    Carp::croak(
+        sprintf qq["%s" is not a parent class of "%s"],
+        $parent, $class
+    ) unless $class->isa($parent);
 
     my @isa = $self->linear_isa();
 
